/*
 *  Copyright (C) 1999 Peter Amstutz
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 2 of *the
 *  License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
 *  02111-1307 USA 
 */
#ifndef _KSERVER_H_
#define _KSERVER_H_

#include "cfgfile.h"
#include "player.h"
#include "game.h"

extern int gm_current_attacker;
extern Gametype_gm gm_gametype;
extern char gm_activate_shots;
extern int gm_shotgeneration;
extern int gm_capital, gm_bounty, gm_stipend;

void svProcessDeathQueue();
void svSendWind(int *who);
void svCommandLine();
void svCommandParse(char *buf);
void svCommandListPlayers();
void svCommandHelp();
#endif
